@@ -23,7 +23,7 @@
 ## Created: November 2009
 ## Version: 0.7
 
-function [H, w, sty, idx] = __frequency_response__ (caller, args, nout = 0)
+function [H, w, sty, idx, H_auto, w_auto] = __frequency_response__ (caller, args, nout = 0)
 
   ## CALLER         | MIMO  | RANGE | CELL  |
   ## ---------------+-------+-------+-------+
@@ -57,7 +57,7 @@ function [H, w, sty, idx] = __frequency_response__ (caller, args, nout = 0)
   inv_idx = ! (sys_idx | w_idx | r_idx | s_idx);    # look for invalid arguments
 
   if (any (inv_idx))
-    warning ("%s: argument(s) number %s are invalid and are being ignored", ...
+    warning ("%s: argument(s) number %s are invalid and are being ignored\n", ...
              caller, mat2str (find (inv_idx)(:).'));
   endif
 
@@ -74,13 +74,14 @@ function [H, w, sty, idx] = __frequency_response__ (caller, args, nout = 0)
   endif
 
   if (any (find (s_idx) < find (sys_idx)(1)))
-    warning ("%s: strings in front of first LTI model are being ignored", caller);
+    warning ("%s: strings in front of first LTI model are being ignored\n", caller);
   endif
 
   ## determine frequency vectors
+  w_auto = __frequency_vector__ (args(sys_idx), wbounds);
   if (any (r_idx))                                  # if there are frequency ranges
     if (nnz (r_idx) > 1)
-      warning ("%s: several frequency ranges specified, taking the last one", caller);
+      warning ("%s: several frequency ranges specified, taking the last one\n", caller);
     endif
     r = args(r_idx){end};
     if (numel (r) == 2 && issample (r{1}) && issample (r{2}) && r{1} < r{2})
@@ -90,12 +91,12 @@ function [H, w, sty, idx] = __frequency_response__ (caller, args, nout = 0)
     endif
   elseif (any (w_idx))                              # are there any frequency vectors?
     if (nnz (r_idx) > 1)
-      warning ("%s: several frequency vectors specified, taking the last one", caller);
+      warning ("%s: several frequency vectors specified, taking the last one\n", caller);
     endif
     w = args(w_idx){end};
     w = repmat ({w}, 1, nnz (sys_idx));
   else                                              # there are neither frequency ranges nor vectors    
-    w = __frequency_vector__ (args(sys_idx), wbounds);
+    w = w_auto;
   endif
 
   ## temporarily save frequency vectors of FRD models
@@ -104,6 +105,7 @@ function [H, w, sty, idx] = __frequency_response__ (caller, args, nout = 0)
 
   ## compute frequency response H for all LTI models
   H = cellfun (@__freqresp__, args(sys_idx), w, {cellflag}, "uniformoutput", false);
+  H_auto = cellfun (@__freqresp__, args(sys_idx), w_auto, {cellflag}, "uniformoutput", false);
 
   ## restore frequency vectors of FRD models in w
   w(frd_idx) = w_frd;
