@@ -49,10 +49,11 @@ extern "C"
 
 // PKG_ADD: autoload ("__sl_sb03md__", "__control_slicot_functions__.oct");    
 DEFUN_DLD (__sl_sb03md__, args, nargout,
-   "-*- texinfo -*-\n\
-Slicot SB03MD Release 5.0\n\
-No argument checking.\n\
-For internal use only.")
+   "-*- texinfo -*-\n"
+   "@deftypefn {} __sl_sb03md__ (@dots{})\n"
+   "Wrapper for SLICOT function SB03MD.@*\n"
+   "For internal use only.\n"
+   "@end deftypefn")
 {
     octave_idx_type nargin = args.length ();
     octave_value_list retval;
@@ -73,6 +74,9 @@ For internal use only.")
         Matrix c = args(1).matrix_value ();
         F77_INT discrete = args(2).int_value ();
         
+        if (a.any_element_is_inf_or_nan () || c.any_element_is_inf_or_nan ())
+          error ("__sl_sb03md__: inputs must not contain NaN or Inf\n");
+
         if (discrete == 0)
           dico = 'C';
         else
