@@ -60,10 +60,11 @@ extern "C"
 
 // PKG_ADD: autoload ("__sl_sb10ad__", "__control_slicot_functions__.oct");    
 DEFUN_DLD (__sl_sb10ad__, args, nargout,
-   "-*- texinfo -*-\n\
-Slicot SB10AD Release 5.0\n\
-No argument checking.\n\
-For internal use only.")
+   "-*- texinfo -*-\n"
+   "@deftypefn {} __sl_sb10ad__ (@dots{})\n"
+   "Wrapper for SLICOT function SB10AD.@*\n"
+   "For internal use only.\n"
+   "@end deftypefn")
 {
     octave_idx_type nargin = args.length ();
     octave_value_list retval;
@@ -80,6 +81,10 @@ For internal use only.")
         Matrix c = args(2).matrix_value ();
         Matrix d = args(3).matrix_value ();
         
+        if (a.any_element_is_inf_or_nan () || b.any_element_is_inf_or_nan () ||
+            c.any_element_is_inf_or_nan () || d.any_element_is_inf_or_nan ())
+          error ("__sl_sb10ad__: inputs must not contain NaN or Inf\n");
+
         F77_INT ncon = args(4).int_value ();
         F77_INT nmeas = args(5).int_value ();
         double gamma = args(6).double_value ();
