@@ -52,10 +52,11 @@ extern "C"
 
 // PKG_ADD: autoload ("__sl_sb10id__", "__control_slicot_functions__.oct");    
 DEFUN_DLD (__sl_sb10id__, args, nargout,
-   "-*- texinfo -*-\n\
-Slicot SB10ID Release 5.0\n\
-No argument checking.\n\
-For internal use only.")
+   "-*- texinfo -*-\n"
+   "@deftypefn {} __sl_sb10id__ (@dots{})\n"
+   "Wrapper for SLICOT function SB10ID.@*\n"
+   "For internal use only.\n"
+   "@end deftypefn")
 {
     octave_idx_type nargin = args.length ();
     octave_value_list retval;
@@ -72,6 +73,10 @@ For internal use only.")
         Matrix c = args(2).matrix_value ();
         Matrix d = args(3).matrix_value ();
         
+        if (a.any_element_is_inf_or_nan () || b.any_element_is_inf_or_nan () ||
+            c.any_element_is_inf_or_nan () || d.any_element_is_inf_or_nan ())
+          error ("__sl_sb10id__: inputs must not contain NaN or Inf\n");
+
         double factor = args(4).double_value ();
         
         F77_INT n = TO_F77_INT (a.rows ());      // n: number of states
