@@ -46,10 +46,11 @@ extern "C"
 
 // PKG_ADD: autoload ("__sl_sb10jd__", "__control_slicot_functions__.oct");    
 DEFUN_DLD (__sl_sb10jd__, args, nargout,
-   "-*- texinfo -*-\n\
-Slicot SB10JD Release 5.0\n\
-No argument checking.\n\
-For internal use only.")
+   "-*- texinfo -*-\n"
+   "@deftypefn {} __sl_sb10jd__ (@dots{})\n"
+   "Wrapper for SLICOT function SB10JD.@*\n"
+   "For internal use only.\n"
+   "@end deftypefn")
 {
     octave_idx_type nargin = args.length ();
     octave_value_list retval;
@@ -67,6 +68,11 @@ For internal use only.")
         Matrix d = args(3).matrix_value ();
         Matrix e = args(4).matrix_value ();
         
+        if (a.any_element_is_inf_or_nan () || b.any_element_is_inf_or_nan () ||
+            c.any_element_is_inf_or_nan () || d.any_element_is_inf_or_nan () ||
+            d.any_element_is_inf_or_nan ())
+          error ("__sl_sb10jd__: inputs must not contain NaN or Inf\n");
+
         F77_INT n = TO_F77_INT (a.rows ());      // n: number of states
         F77_INT m = TO_F77_INT (b.columns ());   // m: number of inputs
         F77_INT np = TO_F77_INT (c.rows ());     // np: number of outputs
