@@ -53,10 +53,11 @@ extern "C"
 
 // PKG_ADD: autoload ("__sl_sg03ad__", "__control_slicot_functions__.oct");    
 DEFUN_DLD (__sl_sg03ad__, args, nargout,
-   "-*- texinfo -*-\n\
-Slicot SG03AD Release 5.0\n\
-No argument checking.\n\
-For internal use only.")
+   "-*- texinfo -*-\n"
+   "@deftypefn {} __sl_sg03ad__ (@dots{})\n"
+   "Wrapper for SLICOT function SG03AD.@*\n"
+   "For internal use only.\n"
+   "@end deftypefn")
 {
     octave_idx_type nargin = args.length ();
     octave_value_list retval;
@@ -79,6 +80,10 @@ For internal use only.")
         Matrix x = args(2).matrix_value ();
         F77_INT discrete = args(3).int_value ();
         
+        if (a.any_element_is_inf_or_nan () || e.any_element_is_inf_or_nan () ||
+            x.any_element_is_inf_or_nan ())
+        error ("__sl_sg03ad__: inputs must not contain NaN or Inf\n");
+
         if (discrete == 0)
           dico = 'C';
         else
